@@ -19,10 +19,7 @@ install() {
     # TODO(bnemec): At some point this will need to be extended to support
     # Python 3, but for the moment we aren't using that anyway.
     inst /usr/bin/python
-    for i in $(find /usr/lib64/python2.7/ -type f); do
-        inst $i
-    done
-    for i in $(find /usr/lib/python2.7/ -type f); do
-        inst $i
-    done
+    while IFS='' read -r -d '' i; do
+        inst "$i"
+    done < <(find /usr/lib64/python2.7/ /usr/lib/python2.7/ -type f -print0)
 }
